@@ -42,6 +42,7 @@ class DottedOrNone(DottedObjectName):
     default_value = ""
 
     def validate(self, obj, value):
+        """Validate an input."""
         if value is not None and len(value) > 0:
             return super().validate(obj, value)
         else:
@@ -194,11 +195,11 @@ class NbConvertApp(JupyterApp):
     def _log_level_default(self):
         return logging.INFO
 
-    classes = List()
+    classes = List()  # type:ignore
 
     @default("classes")
     def _classes_default(self):
-        classes = [NbConvertBase]
+        classes: list = [NbConvertBase]
         for pkg in (exporters, preprocessors, writers, postprocessors):
             for name in dir(pkg):
                 cls = getattr(pkg, name)
@@ -207,7 +208,7 @@ class NbConvertApp(JupyterApp):
 
         return classes
 
-    description = Unicode(
+    description = Unicode(  # type:ignore
         """This application is used to convert notebook files (*.ipynb)
         to various other formats.
 
@@ -644,7 +645,10 @@ class NbConvertApp(JupyterApp):
 
 
 class DejavuApp(NbConvertApp):
+    """A deja vu app."""
+
     def initialize(self, argv=None):
+        """Initialize the app."""
         self.config.TemplateExporter.exclude_input = True
         self.config.TemplateExporter.exclude_output_prompt = True
         self.config.TemplateExporter.exclude_input_prompt = True
@@ -655,7 +659,7 @@ class DejavuApp(NbConvertApp):
         super().initialize(argv)
 
     @default("export_format")
-    def default_export_format(self):
+    def _default_export_format(self):
         return "html"
 
 
